# Generated by Django 4.2.13 on 2024-11-21 17:32

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("manabi_migrations", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="lock",
            name="token",
            field=models.CharField(max_length=255, primary_key=True, serialize=False),
        ),
    ]
